![unimport](https://raw.githubusercontent.com/hakancelik96/unimport/master/images/logo/Unimport.png)

**A linter & formatter for finding & removing unused import statements.**

![pre-commit](https://github.com/hakancelik96/unimport/workflows/pre-commit/badge.svg)
![test](https://github.com/hakancelik96/unimport/workflows/Test/badge.svg)

[![Forks](https://img.shields.io/github/forks/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/fork)
[![Issues](https://img.shields.io/github/issues/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/issues)
[![License](https://img.shields.io/github/license/hakancelik96/unimport.svg)](https://github.com/hakancelik96/unimport/blob/master/LICENSE)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/unimport)
[![Pypi](https://img.shields.io/pypi/v/unimport)](https://pypi.org/project/unimport/)
[![Stars](https://img.shields.io/github/stars/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/stargazers)

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/3fbd4686e97b4e19906ca2fa933e4cfc)](https://app.codacy.com/manual/hakancelik96/unimport?utm_source=github.com&utm_medium=referral&utm_content=hakancelik96/unimport&utm_campaign=Badge_Grade_Settings)
[![Codecov](https://codecov.io/gh/hakancelik96/unimport/branch/master/graph/badge.svg)](https://codecov.io/gh/hakancelik96/unimport)
[![Style](https://img.shields.io/badge/style-black-black)](https://github.com/psf/black)

[![Contributors](https://img.shields.io/github/contributors/hakancelik96/unimport)](https://github.com/hakancelik96/unimport/graphs/contributors)
[![Last Commit](https://img.shields.io/github/last-commit/hakancelik96/unimport.svg)](https://github.com/hakancelik96/unimport/commits/master)

[![Pepy](https://pepy.tech/badge/unimport)](https://pepy.tech/badge/unimport)

For more information see: https://unimport.hakancelik.dev/
